/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.samza.operators;

import java.io.Serializable;
import org.apache.samza.table.Table;
import org.apache.samza.table.TableSpec;


/**
 * This class is the holder of a {@link TableSpec}
 */
public class TableImpl implements Table, Serializable {

  private final TableSpec tableSpec;

  public TableImpl(TableSpec tableSpec) {
    this.tableSpec = tableSpec;
  }

  public TableSpec getTableSpec() {
    return tableSpec;
  }

}
